MODULE in_out_manager   
   !!======================================================================
   !!                       ***  MODULE  in_out_manager  ***
   !! I/O manager utilities : Defines run parameters together with logical units
   !!=====================================================================
   !! History :   1.0  !  2002-06  (G. Madec)   original code
   !!             2.0  !  2006-07  (S. Masson)  iom, add ctl_stop, ctl_warn
   !!             3.0  !  2008-06  (G. Madec)   add ctmp4 to ctmp10
   !!             3.2  !  2009-08  (S. MAsson)  add new ctl_opn
   !!             3.3  !  2010-10  (A. Coward)  add NetCDF4 usage

   !!                     2018-11  (M.Bell)  Totally stripped down version with values explicitly set 

   !!----------------------------------------------------------------------

   !!----------------------------------------------------------------------
   USE par_kind
   IMPLICIT NONE
   PUBLIC

   !!----------------------------------------------------------------------
   !!                        logical units
   !!----------------------------------------------------------------------
   INTEGER ::   numout          =    6      !: logical unit for output print; Set to stdout to ensure any
      !                                     !  early output can be collected; do not change
   INTEGER ::   numnam_ref      =    7      !: logical unit for reference namelist
   INTEGER ::   numnam_cfg      =    8      !: logical unit for configuration specific namelist
   INTEGER ::   numond          =   -1      !: logical unit for Output Namelist Dynamics

   !!----------------------------------------------------------------------
   !!                          Run control  
   !!----------------------------------------------------------------------
   LOGICAL       ::   lwm            = .FALSE.    !: boolean : true on the 1st processor only (always)
   LOGICAL       ::   lwp            = .TRUE.     !: boolean : true on the 1st processor only .OR. ln_ctl

   LOGICAL       ::   ln_timing      = .FALSE.    !:  having to suppress timing calls at the moment anyway

   INTEGER ::   nn_print  = 1       !: level of print (0 no print)
   INTEGER ::   nprint    = 1       !: OLD namelist names

   CHARACTER(lc) ::   ctmp1, ctmp2, ctmp3   !: temporary characters 1 to 3
   CHARACTER(lc) ::   cform_err = "(/,' ===>>> : E R R O R',     /,'         ===========',/)"       !:
   CHARACTER(lc) ::   cform_war = "(/,' ===>>> : W A R N I N G', /,'         ===============',/)"   !:

   REAL(wp) :: hpg_zco_time, hpg_zps_time, hpg_sco_time
   REAL(wp) :: zps_hde_time, eos_time, eos2d_time
   REAL(wp) :: diffusion_time



   !!----------------------------------------------------------------------
   !! NEMO/OPA 4.0 , NEMO Consortium (2018)
   !! $Id: in_out_manager.F90 9490 2018-04-23 08:44:07Z gm $
   !! Software governed by the CeCILL licence     (NEMOGCM/NEMO_CeCILL.txt)
   !!=====================================================================
END MODULE in_out_manager
